reader

package
v0.1.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ImportEnvFile

func ImportEnvFile(path string) (*compose.Project, error)

ImportEnvFile reads a .env file and converts it to an envy compose.

func Merge

func Merge(manifests ...*compose.Project) *compose.Project

Merge combines multiple manifests into a single compose. Services are appended, sets are merged with later sources overwriting earlier ones. Variables within sets are merged with later sources providing defaults for missing vars.

Types

This section is empty.

Jump to