reader

package
v0.1.23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package reader converts external config formats into envy manifests.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ImportCompose

func ImportCompose(path string) (*manifest.Manifest, error)

ImportCompose reads a compose file and converts it to an envy manifest.

func ImportEnvFile

func ImportEnvFile(path string) (*manifest.Manifest, error)

ImportEnvFile reads a .env file and converts it to an envy manifest.

func Merge

func Merge(manifests ...*manifest.Manifest) *manifest.Manifest

Merge combines multiple manifests into a single manifest. Services are appended, sets are merged with later sources overwriting earlier ones. Variables within sets are merged with later sources providing defaults for missing vars.

Types

This section is empty.

Jump to