Documentation
¶
Overview ¶
Package reader converts external config formats into envy manifests.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ImportCompose ¶
ImportCompose reads a compose file and converts it to an envy manifest.
func ImportEnvFile ¶
ImportEnvFile reads a .env file and converts it to an envy manifest.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.